Module playdate_graphics::bitmap
source · Re-exports
pub use crate::BitmapFlipExt;pub use crate::BitmapDrawModeExt;
Modules
- Playdate bitmap-table API
Structs
- The data is 1 bit per pixel packed format, in MSB order; in other words, the high bit of the first byte in data is the top left pixel of the image.
Enums
Traits
Functions
- Resets drawing context for drawing into the system display framebuffer.
- Returns a copy the contents of the working frame buffer as a bitmap.
- Only valid in the Simulator, returns the debug framebuffer as a bitmap.
- Returns a bitmap containing the contents of the display buffer.
- Pops a context off the stack (if any are left), restoring the drawing settings from before the context was pushed.
- Push a new drawing context for drawing into the given bitmap.
- Sets the mode used for drawing bitmaps.
- Sets the stencil used for drawing. For a tiled stencil, use
set_stencil_tiledinstead. - Sets the stencil used for drawing.