pub fn push_context(target: &impl AnyBitmap)
Push a new drawing context for drawing into the given bitmap.

If underlying ptr in the target is null, the drawing functions will use the display framebuffer. This mostly should not happen, just for note.

To clear entire context use clear_context.

This function is shorthand for Graphics::push_context, using default ZST end-point.

Equivalent to sys::ffi::playdate_graphics::pushContext.