pub struct BitmapData<'bitmap> {
    pub width: c_int,
    pub height: c_int,
    pub row_bytes: c_int,
    /* private fields */
}
The data is 1 bit per pixel packed format, in MSB order; in other words, the high bit of the first byte in data is the top left pixel of the image.

The mask data is in same format but means transparency.

Fields

width: c_intheight: c_introw_bytes: c_int

Implementations

source

impl<'bitmap> BitmapData<'bitmap>

source

pub const fn width(&self) -> c_int

source

pub const fn height(&self) -> c_int

source

pub const fn row_bytes(&self) -> c_int

source

pub fn mask(&self) -> Option<&[u8]>

source

pub fn mask_mut(&mut self) -> Option<&mut [u8]>

source

pub const fn data(&self) -> &[u8]

source

pub fn data_mut(&mut self) -> &mut [u8]