pub struct BitmapTable<Api: Api = Default, const FREE_ON_DROP: bool = true>(/* private fields */);Implementations
Sourceimpl<Api: Api> BitmapTable<Api, true>
impl<Api: Api> BitmapTable<Api, true>
Sourcepub fn new(count: c_int, width: c_int, height: c_int) -> Result<Self, Error>where
Api: Default,
pub fn new(count: c_int, width: c_int, height: c_int) -> Result<Self, Error>where
Api: Default,
Allocates and returns a new BitmapTable that can hold count width by height Bitmaps.
Equivalent to sys::ffi::playdate_graphics::newBitmapTable.
Sourcepub fn new_with(
api: Api,
count: c_int,
width: c_int,
height: c_int,
) -> Result<Self, Error>
pub fn new_with( api: Api, count: c_int, width: c_int, height: c_int, ) -> Result<Self, Error>
Allocates and returns a new BitmapTable that can hold count width by height Bitmaps,
using the given api.
Equivalent to sys::ffi::playdate_graphics::newBitmapTable.
Sourcepub fn load<P: AsRef<Path>>(path: P) -> Result<Self, ApiError>where
Api: Default,
pub fn load<P: AsRef<Path>>(path: P) -> Result<Self, ApiError>where
Api: Default,
Allocates and returns a new BitmapTable from the file at path.
If there is no file at path, the function returns error.
Sourcepub fn load_with<P: AsRef<Path>>(api: Api, path: P) -> Result<Self, ApiError>
pub fn load_with<P: AsRef<Path>>(api: Api, path: P) -> Result<Self, ApiError>
Allocates and returns a new BitmapTable from the file at path.
If there is no file at path, the function returns error.
Sourceimpl<Api: Api, const FOD: bool> BitmapTable<Api, FOD>
impl<Api: Api, const FOD: bool> BitmapTable<Api, FOD>
Sourcepub fn load_into<P: AsRef<Path>>(&mut self, path: P) -> Result<(), ApiError>
pub fn load_into<P: AsRef<Path>>(&mut self, path: P) -> Result<(), ApiError>
Loads the image-table at path into the previously allocated this table.
Equivalent to sys::ffi::playdate_graphics::loadIntoBitmapTable.
Sourcepub fn get<'table, BitApi>(
&'table self,
index: c_int,
) -> Option<Bitmap<BitApi, true>>
pub fn get<'table, BitApi>( &'table self, index: c_int, ) -> Option<Bitmap<BitApi, true>>
Returns the index bitmap in this table,
if index is out of bounds, the function returns None.
Creates new default api access-point.
Equivalent to sys::ffi::playdate_graphics::getTableBitmap.
Sourcepub fn get_with<'table, BitApi: BitmapApi>(
&'table self,
api: BitApi,
index: c_int,
) -> Option<Bitmap<BitApi, true>>where
Bitmap<BitApi, true>: 'table,
pub fn get_with<'table, BitApi: BitmapApi>(
&'table self,
api: BitApi,
index: c_int,
) -> Option<Bitmap<BitApi, true>>where
Bitmap<BitApi, true>: 'table,
Returns the index bitmap in this table,
if index is out of bounds, the function returns None.
Produced Bitmap uses passed api access-point.
Equivalent to sys::ffi::playdate_graphics::getTableBitmap.
Sourcepub fn info<'table, BitApi: BitmapApi>(
&'table self,
count: Option<&mut c_int>,
width: Option<&mut c_int>,
)
pub fn info<'table, BitApi: BitmapApi>( &'table self, count: Option<&mut c_int>, width: Option<&mut c_int>, )
Returns the bitmap table’s image count in the count if not None
and number of cells across in the width (ditto) if not None .
Equivalent to sys::ffi::playdate_graphics::getTableBitmap.