pub struct BitmapTable<Api: Api = Default, const FREE_ON_DROP: bool = true>(/* private fields */);

Implementations

source

impl<Api: Api> BitmapTable<Api, true>

source

pub fn new(count: c_int, width: c_int, height: c_int) -> Result<Self, Error>where Api: Default,

Allocates and returns a new BitmapTable that can hold count width by height Bitmaps.

Equivalent to sys::ffi::playdate_graphics::newBitmapTable.

source

pub fn new_with( api: Api, count: c_int, width: c_int, height: c_int ) -> Result<Self, Error>

Allocates and returns a new BitmapTable that can hold count width by height Bitmaps, using the given api.

Equivalent to sys::ffi::playdate_graphics::newBitmapTable.

source

pub fn load<P: AsRef<Path>>(path: P) -> Result<Self, ApiError>where Api: Default,

Allocates and returns a new BitmapTable from the file at path.

If there is no file at path, the function returns error.

Calls sys::ffi::playdate_graphics::loadBitmapTable.

source

pub fn load_with<P: AsRef<Path>>(api: Api, path: P) -> Result<Self, ApiError>

Allocates and returns a new BitmapTable from the file at path.

If there is no file at path, the function returns error.

Calls sys::ffi::playdate_graphics::loadBitmapTable.

source

impl<Api: Api, const FOD: bool> BitmapTable<Api, FOD>

source

pub fn load_into<P: AsRef<Path>>(&mut self, path: P) -> Result<(), ApiError>

Loads the image-table at path into the previously allocated this table.

Equivalent to sys::ffi::playdate_graphics::loadIntoBitmapTable.

source

pub fn get<'table, BitApi>( &'table self, index: c_int ) -> Option<Bitmap<BitApi, true>>where Bitmap<BitApi, true>: 'table, BitApi: Default + BitmapApi,

Returns the index bitmap in this table, if index is out of bounds, the function returns None.

Creates new default api access-point.

Equivalent to sys::ffi::playdate_graphics::getTableBitmap.

source

pub fn get_with<'table, BitApi: BitmapApi>( &'table self, api: BitApi, index: c_int ) -> Option<Bitmap<BitApi, true>>where Bitmap<BitApi, true>: 'table,

Returns the index bitmap in this table, if index is out of bounds, the function returns None.

Produced Bitmap uses passed api access-point.

Equivalent to sys::ffi::playdate_graphics::getTableBitmap.